@@ -106,10 +106,10 @@ FileViewBazaarPlugin::FileViewBazaarPlugin(QObject* parent, const QList<QVariant
     connect(m_logAction, SIGNAL(triggered()),
             this, SLOT(log()));
 
-    connect(&m_process, SIGNAL(finished(int, QProcess::ExitStatus)),
-            this, SLOT(slotOperationCompleted(int, QProcess::ExitStatus)));
-    connect(&m_process, SIGNAL(error(QProcess::ProcessError)),
-            this, SLOT(slotOperationError()));
+    connect(&m_process, QOverload<int, QProcess::ExitStatus>::of(&QProcess::finished),
+            this, &FileViewBazaarPlugin::slotOperationCompleted);
+    connect(&m_process, &QProcess::errorOccurred,
+            this, &FileViewBazaarPlugin::slotOperationError);
 }
 
 FileViewBazaarPlugin::~FileViewBazaarPlugin()
@@ -136,7 +136,7 @@ bool FileViewBazaarPlugin::beginRetrieval(const QString& directory)
         }
     }
     // if bzr is not installed
-    if (baseDir == "") {
+    if (baseDir.isEmpty()) {
             return false;
     }
 
@@ -157,8 +157,8 @@ bool FileViewBazaarPlugin::beginRetrieval(const QString& directory)
         char buffer[512];
         while (process2.readLine(buffer, sizeof(buffer)) > 0)  {
             QString line = QString(buffer).trimmed();
-            QStringList list = line.split(" ");
-            QString file = baseDir + "/" + list[0];
+            QStringList list = line.split(' ');
+            QString file = baseDir + '/' + list[0];
             m_versionInfoHash.insert(file, UnversionedVersion);
         }
     }
@@ -201,9 +201,9 @@ bool FileViewBazaarPlugin::beginRetrieval(const QString& directory)
                 if (filePath.startsWith("C   Text conflict")) {
                     filePath = filePath.mid(17, length);
                 }
-                filePath = baseDir + "/" + filePath.mid(pos, length);
+                filePath = baseDir + '/' + filePath.mid(pos, length);
                 //remove type symbols from directories, links and executables
-                if (filePath.endsWith("/") || filePath.endsWith("@") || filePath.endsWith("*")) {
+                if (filePath.endsWith('/') || filePath.endsWith('@') || filePath.endsWith('*')) {
                     filePath = filePath.left(filePath.length() - 1);
                 }
                 if (!filePath.isEmpty()) {
